@@ -182,11 +182,11 @@ is_in_filesystem_file (const gchar *filesystems_file,
                             NULL, /* gsize *out_length */
                             &error))
     {
-      g_warning ("Error reading %s: %s (%s %d)",
-                 filesystems_file,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      udisks_warning ("Error reading %s: %s (%s %d)",
+                      filesystems_file,
+                      error->message,
+                      g_quark_to_string (error->domain),
+                      error->code);
       g_error_free (error);
       goto out;
     }
@@ -328,7 +328,7 @@ find_primary_gid (uid_t uid)
   pw = getpwuid (uid);
   if (pw == NULL)
     {
-      g_warning ("Couldn't look up uid %d: %m", uid);
+      udisks_warning ("Error looking up uid %d: %m", uid);
       goto out;
     }
   gid = pw->pw_gid;
@@ -354,7 +354,7 @@ is_uid_in_gid (uid_t uid,
   pw = getpwuid (uid);
   if (pw == NULL)
     {
-      g_warning ("Couldn't look up uid %d: %m", uid);
+      udisks_warning ("Error looking up uid %d: %m", uid);
       goto out;
     }
   if (pw->pw_gid == gid)
@@ -365,7 +365,7 @@ is_uid_in_gid (uid_t uid,
 
   if (getgrouplist (pw->pw_name, pw->pw_gid, supplementary_groups, &num_supplementary_groups) < 0)
     {
-      g_warning ("Couldn't find supplementary groups for uid %d: %m", uid);
+      udisks_warning ("Error getting supplementary groups for uid %d: %m", uid);
       goto out;
     }
 
@@ -564,14 +564,11 @@ subst_str_and_escape (const gchar *str,
                       const gchar *from,
                       const gchar *to)
 {
-  gchar *escaped;
   gchar *quoted_and_escaped;
   gchar *ret;
-  escaped = g_strescape (to, NULL);
-  quoted_and_escaped = g_strconcat ("\"", escaped, "\"", NULL);
+  quoted_and_escaped = udisks_daemon_util_escape_and_quote (to);
   ret = subst_str (str, from, quoted_and_escaped);
   g_free (quoted_and_escaped);
-  g_free (escaped);
   return ret;
 }
 
@@ -800,12 +797,10 @@ calculate_mount_point (UDisksBlock               *block,
       uuid = udisks_block_get_id_uuid (block);
     }
 
-  /* If we know the user-name, mount in /run/media/$USER */
-  if (user_name != NULL)
+  /* If we know the user-name and it doesn't have any '/' character in it, mount in /run/media/$USER */
+  if (user_name != NULL && strstr (user_name, "/") == NULL)
     {
-      escaped_user_name = g_strescape (user_name, NULL);;
-
-      mount_dir = g_strdup_printf ("/run/media/%s", escaped_user_name);
+      mount_dir = g_strdup_printf ("/run/media/%s", user_name);
       if (!g_file_test (mount_dir, G_FILE_TEST_EXISTS))
         {
           gchar *stderr_txt;
@@ -834,6 +829,7 @@ calculate_mount_point (UDisksBlock               *block,
               goto out;
             }
           /* Then set the ACL such that only $USER can actually access it */
+          escaped_user_name = udisks_daemon_util_escape (user_name);;
           s = g_strdup_printf ("setfacl -m \"u:%s:rx\" \"%s\"",
                                escaped_user_name,
                                mount_dir);
@@ -1155,15 +1151,6 @@ handle_mount (UDisksFilesystem       *filesystem,
       goto out;
     }
 
-  /* if system-managed (e.g. referenced in /etc/fstab or similar), then
-   *
-   * - if the option x-udisks-auth is given, then just run mount(8) as
-   *   the calling user; if that fails because of permission denied
-   *   try running it as root after the user authenticates for the
-   *   action org.freedesktop.udisks2.filesystem-fstab
-   *
-   * - otherwise (default case), use the normal authorization checks
-   */
   if (system_managed)
     {
       gint status;
@@ -1199,7 +1186,7 @@ handle_mount (UDisksFilesystem       *filesystem,
             }
         }
 
-      escaped_mount_point_to_use   = g_strescape (mount_point_to_use, NULL);
+      escaped_mount_point_to_use   = udisks_daemon_util_escape_and_quote (mount_point_to_use);
     mount_fstab_again:
       if (!udisks_daemon_launch_spawned_job_sync (daemon,
                                                   object,
@@ -1209,7 +1196,7 @@ handle_mount (UDisksFilesystem       *filesystem,
                                                   &status,
                                                   &error_message,
                                                   NULL,  /* input_string */
-                                                  "mount \"%s\"",
+                                                  "mount %s",
                                                   escaped_mount_point_to_use))
         {
           /* mount(8) exits with status 1 on "incorrect invocation or permissions" - if this is
@@ -1343,10 +1330,10 @@ handle_mount (UDisksFilesystem       *filesystem,
       goto out;
     }
 
-  escaped_fs_type_to_use       = g_strescape (fs_type_to_use, NULL);
-  escaped_mount_options_to_use = g_strescape (mount_options_to_use, NULL);
-  escaped_mount_point_to_use   = g_strescape (mount_point_to_use, NULL);
-  escaped_device               = g_strescape (udisks_block_get_device (block), NULL);
+  escaped_fs_type_to_use       = udisks_daemon_util_escape_and_quote (fs_type_to_use);
+  escaped_mount_options_to_use = udisks_daemon_util_escape_and_quote (mount_options_to_use);
+  escaped_mount_point_to_use   = udisks_daemon_util_escape_and_quote (mount_point_to_use);
+  escaped_device               = udisks_daemon_util_escape_and_quote (udisks_block_get_device (block));
 
   /* run mount(8) */
   if (!udisks_daemon_launch_spawned_job_sync (daemon,
@@ -1357,7 +1344,7 @@ handle_mount (UDisksFilesystem       *filesystem,
                                               NULL, /* gint *out_status */
                                               &error_message,
                                               NULL,  /* input_string */
-                                              "mount -t \"%s\" -o \"%s\" \"%s\" \"%s\"",
+                                              "mount -t %s -o %s %s %s",
                                               escaped_fs_type_to_use,
                                               escaped_mount_options_to_use,
                                               escaped_device,
@@ -1505,7 +1492,7 @@ handle_unmount (UDisksFilesystem       *filesystem,
 
       unmount_fstab_as_root = FALSE;
     unmount_fstab_again:
-      escaped_mount_point = g_strescape (mount_point, NULL);
+      escaped_mount_point = udisks_daemon_util_escape_and_quote (mount_point);
       /* right now -l is the only way to "force unmount" file systems... */
       if (!udisks_daemon_launch_spawned_job_sync (daemon,
                                                   object,
@@ -1515,7 +1502,7 @@ handle_unmount (UDisksFilesystem       *filesystem,
                                                   &status,
                                                   &error_message,
                                                   NULL,  /* input_string */
-                                                  "umount %s \"%s\"",
+                                                  "umount %s %s",
                                                   opt_force ? "-l" : "",
                                                   escaped_mount_point))
         {
@@ -1575,12 +1562,12 @@ handle_unmount (UDisksFilesystem       *filesystem,
         goto out;
     }
 
-  escaped_device = g_strescape (udisks_block_get_device (block), NULL);
+  escaped_device = udisks_daemon_util_escape_and_quote (udisks_block_get_device (block));
 
   /* otherwise go ahead and unmount the filesystem */
   if (mount_point != NULL)
     {
-      escaped_mount_point = g_strescape (mount_point, NULL);
+      escaped_mount_point = udisks_daemon_util_escape_and_quote (mount_point);
       rc = udisks_daemon_launch_spawned_job_sync (daemon,
                                                   object,
                                                   NULL, /* GCancellable */
@@ -1589,7 +1576,7 @@ handle_unmount (UDisksFilesystem       *filesystem,
                                                   NULL, /* gint *out_status */
                                                   &error_message,
                                                   NULL,  /* input_string */
-                                                  "umount %s \"%s\"",
+                                                  "umount %s %s",
                                                   opt_force ? "-l" : "",
                                                   escaped_mount_point);
     }
@@ -1604,7 +1591,7 @@ handle_unmount (UDisksFilesystem       *filesystem,
                                                   &status,
                                                   &error_message,
                                                   NULL,  /* input_string */
-                                                  "umount %s \"%s\"",
+                                                  "umount %s %s",
                                                   opt_force ? "-l" : "",
                                                   escaped_device);
     }
